@@ -1,10 +1,14 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
+
 import os
 from .arg_parse import arg_parse
 
 home_dir = os.path.expanduser("~")
 config_file = home_dir + "/.config/robin/software_deployment.yaml"
 
-if __name__ == '__main__':
-    arg_parse(config_file)
\ No newline at end of file
+def main():
+    arg_parse(config_file)
+
+if __name__ == "__main__":
+    main()
\ No newline at end of file
