@@ -30,13 +30,17 @@ def arg_parse(config_file):
 
     if args.check:
         parse_config(config_file)
-        check_upload_file(upload_file_path)
         exit(0)
     elif args.upload:
+        #check if type,version,source are given
+        if radarType is None or version_name is None or upload_file_path is None:
+            print('Please provide all the arguments: --type, --version, --source')
+            exit(1)
         parse_config(config_file)
         validate(radarType, version_name)
-        check_upload_file(upload_file_path)
-
+        # if check_upload_file return false, exit
+        if check_upload_file(upload_file_path) is False:
+            exit(1)
         version_dir_to_upload= os.path.join(upload_file_path, version_name)
         zipped_file_path = os.path.join(upload_file_path, version_name + '.zip')
 
